# Taken from pango spec
%define biarchs_32 %{ix86}
%define biarchs_64 x86_64
%define query_modules_suffix %{nil}
%ifarch %{biarchs_32}
%define query_modules_suffix -32
%endif
%ifarch %{biarchs_64}
%define query_modules_suffix -64
%endif
%define query_modules pango-querymodules%{query_modules_suffix}

# for python modules
%define _disable_ld_no_undefined 1

Name:           lilypond
Version:        2.12.3
Release:        %mkrel 1
Epoch:          0
Summary:        Program for printing sheet music
License:        GPL
Group:          Publishing
URL:            http://www.lilypond.org/
Source0:        http://lilypond.org/download/sources/v2.11/%{name}-%{version}.tar.gz
Source2:	http://download.linuxaudio.org/lilypond/binaries/documentation/%{name}-%{version}-2.documentation.tar.bz2
# (Abel) use locale-independency date as document timestamp
Patch3:         lilypond-2.6.3-locale-indep-date.patch
# (Abel) use ImageMagick to replace netpbm -- pnmtopng segfault
# and I'm too lazy to look into the problem
Patch4:         lilypond-2.6.4-use-imagemagick.patch
Patch5:		lilypond-2.12.2-fix-string-format.patch
Patch6:		lilypond-2.11.65-python26.patch
#Patch7:		lilypond-consts.patch
Suggests:	%{name}-doc = %{version}
Requires(post): ec-fonts-mftraced
Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(post): findutils
Requires(post): tetex
Requires(postun): tetex
# (Abel) bib2html or bibtex2html -- pick either one
BuildRequires:  bib2html
BuildRequires:  bison
BuildRequires:  ec-fonts-mftraced
BuildRequires:  flex
BuildRequires:  fontforge
BuildRequires:  gettext-devel
BuildRequires:  ghostscript
BuildRequires:  groff-for-man
BuildRequires:  gtk2-devel
BuildRequires:  guile-devel >= 1.8.1
BuildRequires:  mftrace
BuildRequires:  python-devel
BuildRequires:  tetex-devel
BuildRequires:  texinfo
BuildRequires:  info-install
BuildRequires:  zip
BuildRequires:  imagemagick
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot 

%description
LilyPond is a music typesetter.  It produces beautiful sheet music using a
high level description file as input.  LilyPond is part of the GNU project.
 
LilyPond is split into two packages.  The package "lilypond" provides the
core package, containing the utilities for converting the music source
(.ly) files into printable output.  The package "lilypond-doc" 
provides the full documentation, example .ly files for various features and 
the Mutopia project files (musical equivalent of the Gutenberg project - see
http://www.mutopiaproject.org for details).
 
If you are new to lilypond, you will almost certainly want to install the
"lilypond-doc" package and take a look at tutorials under
%{_docdir}/lilypond-doc.

%package doc
Summary:        LilyPond documentation, examples and Mutopia files
Group:          Publishing
Obsoletes:      %{name}-manual
Provides:       %{name}-manual
Requires(post): rarian
Requires(postun): rarian

%description doc
The documentation of LilyPond, both in HTML and PostScript, along with
example input files and the files from the Mutopia project. If you
want to try the examples or score files from Mutopia project, please
also install LilyPond main package.


%prep
%setup -q
%patch3 -p1 -b .date
%patch4 -p1 -b .netpbm
%patch5 -p0
%patch6 -p0
#%patch7 -p1

mkdir -p %{name}-documentation-%{version}
cd %{name}-documentation-%{version}
bunzip2 -dcq %SOURCE2 | tar -xf -
cd -

%build
#
# build environment untrustworthy
#
%{_bindir}/%query_modules > pango.modules
echo "[Pango]" > pangorc
echo "ModuleFiles = `pwd`/pango.modules" >> pangorc
export PANGO_RC_FILE=`pwd`/pangorc

#
# build timestamp in HTML can be affected by locale
# (not necessary after applying date patch)
#
#export LC_TIME=C
%{configure2_5x} --enable-gui
%{make}

# Doesn't work out of the box for this version.
#%{make} web

%install
%{__rm} -rf %{buildroot}
%{makeinstall_std}

#
# web doc
#
# Doesn't work out of the box for this version.
#%{__make} out=www web-install DESTDIR=%{buildroot}

#
# move emacs file to our location
#
%{__install} -D -m 644 elisp/lilypond-init.el %{buildroot}%{_sysconfdir}/emacs/site-start.d/lilypond-init.el

#
# move vim stuff to our location
#
%{__mv} %{buildroot}%{_datadir}/lilypond/%{version}/vim %{buildroot}%{_datadir}/vim

#
# some more house cleaning
#
%{_bindir}/find %{buildroot} -path '*%{_datadir}/lilypond/%{version}/fonts' -prune -type f -o -name 'fonts.cache-1' -print0 | %{_bindir}/xargs -r -0 %{__rm}
%{_bindir}/find %{buildroot}%{_docdir} -name '*.png' -empty -print0 | %{_bindir}/xargs -r -0 %{__rm}
%{_bindir}/find %{buildroot}%{_datadir}/lilypond/%{version} -xtype l -print0 | %{_bindir}/xargs -r -0 %{__rm}

#
# Create symlinks to lilypond folder under TeX directory, so that TeX can
# use lilypond files natively, courtesy of Michael Brown's great hacks
# Necessary for tex backend to work, since startup profile is gone -- Abel
#
%{__mkdir_p} %{buildroot}%{_datadir}/texmf/dvips \
         %{buildroot}%{_datadir}/texmf/tex \
         %{buildroot}%{_datadir}/texmf/fonts/source \
         %{buildroot}%{_datadir}/texmf/fonts/tfm
pushd %{buildroot}%{_datadir}/texmf > /dev/null
%{__ln_s} ../../lilypond/%{version}/ps dvips/lilypond
%{__ln_s} ../../lilypond/%{version}/tex tex/lilypond
%{__ln_s} ../../../lilypond/%{version}/fonts/source fonts/source/lilypond
%{__ln_s} ../../../lilypond/%{version}/fonts/tfm fonts/tfm/lilypond
popd > /dev/null

%{find_lang} %{name}

mkdir -p %{buildroot}%_sysconfdir/X11/fontpath.d/
ln -s ../../..%_datadir/lilypond/%{version}/fonts/type1 \
    %{buildroot}%_sysconfdir/X11/fontpath.d/lilypond:pri=50


%clean
%{__rm} -rf %{buildroot}

%post
%_install_info lilypond.info
%_install_info lilypond-internals.info
%_install_info lilypond-learning.info
%_install_info lilypond-program.info
%_install_info music-glossary.info

%{_bindir}/find /var/lib/texmf \( -name 'feta*.pk' -or -name 'feta*.tfm' -or -name 'parmesan*.pk' -or -name 'parmesan*.tfm' \) -print0 | %{_bindir}/xargs -r -0 %{__rm} -f

%{_bindir}/mktexlsr > /dev/null

%{_bindir}/mkfontdir %{_datadir}/lilypond/%{version}/fonts/type1

%preun
%_remove_install_info lilypond.info
%_remove_install_info lilypond-learning.info
%_remove_install_info lilypond-internals.info
%_remove_install_info lilypond-program.info
%_remove_install_info music-glossary.info

%{__rm} -f %{_datadir}/lilypond/%{version}/fonts/type1/fonts.dir

%postun
%{_bindir}/mktexlsr > /dev/null

%post doc
%update_scrollkeeper

%postun doc
%clean_scrollkeeper

%files -f %{name}.lang
%defattr(-, root, root)
%doc COPYING README.txt DEDICATION NEWS.txt AUTHORS.txt THANKS
%{_bindir}/*
%{_datadir}/emacs/site-lisp/lilypond*
%{_datadir}/%{name}
%{_datadir}/texmf/dvips/lilypond
%{_datadir}/texmf/fonts/source/lilypond
%{_datadir}/texmf/fonts/tfm/lilypond
%{_datadir}/texmf/tex/lilypond
%{_datadir}/vim/*/*
%{_libdir}/%{name}
%{_mandir}/man?/*
%{_infodir}/*.info*
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/*
%{_sysconfdir}/X11/fontpath.d/lilypond:pri=50

%files doc
%defattr(-, root, root)
%doc %{name}-documentation-%{version}/*
%{_datadir}/omf/%{name}


%changelog
* Mon Feb 15 2010 Emmanuel Andry <eandry@mandriva.org> 0:2.12.3-1mdv2010.1
+ Revision: 506342
- New version 2.12.3
- drop p7 (fixed upstream)
- scrollkeeper is no more, use rarian

  + Funda Wang <fwang@mandriva.org>
    - rebuild for new gmp

* Sun Nov 15 2009 Funda Wang <fwang@mandriva.org> 0:2.12.2-4mdv2010.1
+ Revision: 466139
- patch updated
- fix recognize on python 2.6

  + Thierry Vignaud <tvignaud@mandriva.com>
    - rebuild

* Sat Mar 14 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0:2.12.2-3mdv2009.1
+ Revision: 355056
- rebuild for missing doc package
- keep bash completion in its own package

* Mon Feb 02 2009 Funda Wang <fwang@mandriva.org> 0:2.12.2-1mdv2009.1
+ Revision: 336373
- rediff str fmt patch
- New version 2.12.2

* Sun Jan 18 2009 Funda Wang <fwang@mandriva.org> 0:2.12.1-1mdv2009.1
+ Revision: 330814
- no more utf8 patch
- rediff str fmt patch
- New version 2.12.1

* Wed Dec 17 2008 Funda Wang <fwang@mandriva.org> 0:2.11.65-1mdv2009.1
+ Revision: 315056
- fix string format
- new version 2.11.65

  + Oden Eriksson <oeriksson@mandriva.com>
    - lowercase ImageMagick

* Thu Nov 13 2008 Funda Wang <fwang@mandriva.org> 0:2.11.63-1mdv2009.1
+ Revision: 302686
- New version 2.11.63

* Wed Oct 15 2008 Funda Wang <fwang@mandriva.org> 0:2.11.62-1mdv2009.1
+ Revision: 294003
- rediff utf8 patch
- New version 2.11.62

* Sun Aug 31 2008 Funda Wang <fwang@mandriva.org> 0:2.11.57-1mdv2009.0
+ Revision: 277728
- New version 2.11.57

* Mon Aug 18 2008 Frederik Himpe <fhimpe@mandriva.org> 0:2.11.56-1mdv2009.0
+ Revision: 273414
- update to new version 2.11.56

* Wed Jul 30 2008 Funda Wang <fwang@mandriva.org> 0:2.11.54-1mdv2009.0
+ Revision: 254551
- New version 2.11.54

* Sun Jul 20 2008 Funda Wang <fwang@mandriva.org> 0:2.11.52-1mdv2009.0
+ Revision: 238937
- New version 2.11.52
- New version 2.11.50
- rebuild for new rpm payload

* Sat Jun 07 2008 Funda Wang <fwang@mandriva.org> 0:2.11.47-1mdv2009.0
+ Revision: 216574
- New version 2.11.47

* Tue May 27 2008 Funda Wang <fwang@mandriva.org> 0:2.11.46-1mdv2009.0
+ Revision: 211505
- _disable_ld_no_undefined
- New version 2.11.46

* Fri May 02 2008 Funda Wang <fwang@mandriva.org> 0:2.11.45-1mdv2009.0
+ Revision: 200170
- New version 2.11.45
- New version 2.11.44

* Sun Feb 24 2008 Funda Wang <fwang@mandriva.org> 0:2.11.40-1mdv2008.1
+ Revision: 174321
- fix info files dir
- New version 2.11.40
- New version 2.11.37

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 0:2.11.36-1mdv2008.1
+ Revision: 136572
- restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

  + Funda Wang <fwang@mandriva.org>
    - New version 2.11.36

* Fri Nov 23 2007 Funda Wang <fwang@mandriva.org> 0:2.11.35-1mdv2008.1
+ Revision: 111560
- New version 2.11.35

* Tue Oct 09 2007 Funda Wang <fwang@mandriva.org> 0:2.11.34-1mdv2008.1
+ Revision: 96072
- New version 2.11.34

* Sun Sep 02 2007 Funda Wang <fwang@mandriva.org> 0:2.11.31-1mdv2008.0
+ Revision: 77980
- New version 2.11.31

* Thu Aug 23 2007 Funda Wang <fwang@mandriva.org> 0:2.11.30-1mdv2008.0
+ Revision: 70510
- New version 2.11.30
- small fix on spec

* Mon Aug 13 2007 Funda Wang <fwang@mandriva.org> 0:2.11.29-1mdv2008.0
+ Revision: 62831
- Drop INSTALL.txt
- New version 2.11.29

* Mon Jul 30 2007 Funda Wang <fwang@mandriva.org> 0:2.11.28-1mdv2008.0
+ Revision: 56730
- New version 2.11.28

* Fri Jul 06 2007 Ademar de Souza Reis Jr <ademar@mandriva.com.br> 0:2.11.27-2mdv2008.0
+ Revision: 49234
- fontpath.d conversion (#31756)

* Sat Jun 30 2007 Funda Wang <fwang@mandriva.org> 0:2.11.27-1mdv2008.0
+ Revision: 46006
- New version

* Sun Jun 10 2007 Funda Wang <fwang@mandriva.org> 0:2.11.26-1mdv2008.0
+ Revision: 37786
- New version
- Merge documentation package
- Add documentation

* Thu May 24 2007 Funda Wang <fwang@mandriva.org> 0:2.11.25-1mdv2008.0
+ Revision: 30534
- New upstream version

* Mon May 07 2007 Funda Wang <fwang@mandriva.org> 0:2.11.23-1mdv2008.0
+ Revision: 24119
- New upstream version 2.11.23

* Wed Apr 18 2007 David Walluck <walluck@mandriva.org> 0:2.11.22-1mdv2008.0
+ Revision: 14334
- require ec-fonts-mftraced
- ghostscript-fonts already pulled in by ghostscript
- BuildRequires: ghostscript-fonts
- 2.11.22


* Sat Mar 03 2007 Emmanuel Andry <eandry@mandriva.org> 2.11.20-1mdv2007.0
+ Revision: 131734
- New version 2.11.20

  + Nicolas Lécureuil <neoclust@mandriva.org>
    -New version 2.11.12

* Tue Jan 09 2007 Nicolas Lécureuil <neoclust@mandriva.org> 2.11.10-1mdv2007.1
+ Revision: 106579
- New release

  + David Walluck <walluck@mandriva.org>
    - libguile-devel Requires: libgmp-devel, not lilypond

* Sun Jan 07 2007 David Walluck <walluck@mandriva.org> 2.11.9-4mdv2007.1
+ Revision: 105148
- BuildRequires: gmp-devel
- BuildRequires: gettext-devel
- use versioned guile-devel requirement
- 2.11.9

  + Bruno Cornec <Bruno.Cornec@mandriva.org>
    - Sources are now also updated
    - Updated to 2.8.6
    - Temporarily removed the building of lilypond guide as it wasn't able to build, and I just found analog questions on lilypond ML without any answer. Will test again with next version to see if it's corrected or not.
    - import lilypond-2.6.5-1mdk

* Fri Feb 24 2006 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 2.6.5-1mdk
- New release 2.6.5
- Drop patch 0

* Sun Oct 16 2005 Abel Cheung <deaddog@mandriva.org> 2.6.4-1mdk
- New release 2.6.4
- Drop patch1 (upstream)
- Patch4: netpbm segfaults, so use ImageMagick to replace it

* Wed Aug 17 2005 Abel Cheung <deaddog@mandriva.org> 2.6.3-3mdk
- Fix midi2ly by moving python module to expected location
- Fix bash completion file

* Tue Aug 09 2005 Abel Cheung <deaddog@mandriva.org> 2.6.3-2mdk
- Fix URL
- Some sensible rpmlint fixes

* Sun Aug 07 2005 Abel Cheung <deaddog@mandriva.org> 2.6.3-1mdk
- New release
- Patch3: use locale-independency date as document timestamp, so no need
  to set LC_TIME manually
- Fix directory name during install time (don't hardcode as 2.6.1)

* Wed Jul 27 2005 Abel Cheung <deaddog@mandriva.org> 2.6.1-2mdk
- Patch1: don't mark empty string as translatable, otherwise lilypond-book
  shows .po file header
- Patch2: use utf8 as default encoding for generated tex file
- set LC_TIME during build, otherwise HTML doc contains localized timestamp
- Reintroduce Michael Brown's hacks (aka let TeX read lilypond file natively),
  at least tex backend produces something now, though some problem still
  remains (first page in dvi file contains nothing)

* Sun Jul 24 2005 Abel Cheung <deaddog@mandriva.org> 2.6.1-1mdk
- New release
- Startup profile no more needed
- Drop .scm search path patch (P1), no more necessary
- Build machine broken, avoiding system pango config
- Respect original doc file location (otherwise must modify omf file too)
- Forgot FHS temporarily, involves lots of work
- Reduce destdir patch (P0) to just bare minimum, can't maintain patch
  this way

* Sun Feb 06 2005 Abel Cheung <deaddog@mandrake.org> 2.5.11-1mdk
- 2.5.11
- Merge the work done seperately by:
  o Noam Meltzer <tsnoam@zahav.net.il>
  o Torbjorn Turpeinen <tobbe@nyvalls.se>
  o Heikki Johannes Junes <hjunes@cc.hut.fi>
- Too many changes to list, they mainly include:
  o Remove menu entry
  o Always install info files
  o So called lib package is just python binding, merge into main pkg
  o Clean up some over-usage and under-usage of macros
  o P0: DESTDIR support, replaces patch the just sets vim file path
  o P1: Fix search path for .scm files, build failed

* Tue Nov 09 2004 Noam Meltzer <tsnoam@zahav.net.il> 2.4.2-1_tsn
- change release to 1_tsn and ver. to 2.4.2
- remove the full path reference to mkfontdir
- removing ending slashes from path elements of the font dir
- make some sanity checks before adding/removing fontpath elements

* Sun Nov 07 2004 Noam Meltzer <tsnoam@zahav.net.il> 2.4.1-2_tsn
- change release to 2_tsn
- when doing install-info, point it to the correct path.
- add a patch that willl replace the vimdir inside config.make.in to be $(datadir)/vim
- add /usr/share/vim to the files section

* Sat Nov 06 2004 Noam Meltzer <tsnoam@zahav.net.il> 2.4.1-1_tsn
- change release to 1_tsn and start to add changelog entries :-)
- change the source file to be a tar.gz file (instead of tar.bz2) as downloaded
- change the buildrequires from libMagick5.5.4-devel to just libmMagick5-devel
- add buildrequires: tetex-devel, python-devel
- add a requires: ec-fonts-mftraced
- use the bzip2, mkdir, rm, cp, strip, install & install-info macros instead of calling the commands directly
- fix a bug with the compression of the info files (add another element to the path)
- use only the %%files -f lilypond.lang method to add locales, don't add it twice
- refer to /etc as sysconfdir, and not the ugly earlier way used before
- add more parameters to the configure scripts, according to the 
  CONFIGURE_TOP="${CONFIGURE_TOP:-.}"; 
  CFLAGS="${CFLAGS:--O2 -g -pipe -Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fomit-frame-pointer -march=i586 -mtune=pentiumpro -fasynchronous-unwind-tables}" ; export CFLAGS ; 
  CXXFLAGS="${CXXFLAGS:--O2 -g -pipe -Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fomit-frame-pointer -march=i586 -mtune=pentiumpro -fasynchronous-unwind-tables}" ; export CXXFLAGS ; 
  FFLAGS="${FFLAGS:--O2 -g -pipe -Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fomit-frame-pointer -march=i586 -mtune=pentiumpro -fasynchronous-unwind-tables}" ; export FFLAGS ; 
  cputoolize -c $CONFIGURE_TOP ; 
  (cd $CONFIGURE_TOP; [ -f configure.in -o -f configure.ac ] && libtoolize --copy --force) ; 
  [ -f $CONFIGURE_TOP/configure.in -o -f $CONFIGURE_TOP/configure.ac ] && 
  CONFIGURE_XPATH="--x-includes=/usr/X11R6/include --x-libraries=/usr/X11R6/lib" 
  $CONFIGURE_TOP/configure i586-mandriva-linux-gnu \
	--program-prefix= \
 	--prefix=/usr \
	--exec-prefix=/usr \
	--bindir=/usr/bin \
	--sbindir=/usr/sbin \
	--sysconfdir=/etc \
	--datadir=/usr/share \
	--includedir=/usr/include \
	--libdir=/usr/lib \
	--libexecdir=/usr/lib \
	--localstatedir=/var/lib \
	--sharedstatedir=/usr/com \
	--mandir=/usr/share/man \
	--infodir=/usr/share/info \
    $CONFIGURE_XPATH macro
- build the gnome gui also
- make the link to the Source0 file correct
- use make -j4 instead of make
- when doing 'make web-install', add all the prefixes needed to install it in rpmbuildroot
- add a packager line

* Sat Jul 17 2004 Michael Scherer <misc@mandrake.org> 2.2.0-2mdk 
- rebuild for new gcc

* Sat Apr 03 2004 Austin Acton <austin@mnadrke.org> 2.2.0-1mdk
- 2.2.0

